@@ -6,9 +6,10 @@ require 'rack/multipart'
 
 major, minor, patch = RUBY_VERSION.split('.').map { |v| v.to_i }
 
-if (major == 1 && minor < 9) || (major == 1 && minor == 9 && patch < 2)
-  # pull in backports
-  require 'rack/backports/uri/common'
+if major == 1 && minor < 9
+  require 'rack/backports/uri/common_18'
+elsif major == 1 && minor == 9 && patch < 3
+  require 'rack/backports/uri/common_192'
 else
   require 'uri/common'
 end
@@ -18,7 +19,7 @@ module Rack
   # applications adopted from all kinds of Ruby libraries.
 
   module Utils
-    # URI escapes a string. (CGI style space to +)
+    # URI escapes. (CGI style space to +)
     def escape(s)
       URI.encode_www_form_component(s)
     end
@@ -146,7 +147,13 @@ module Rack
       '"' => "&quot;",
       "/" => "&#x2F;"
     }
-    ESCAPE_HTML_PATTERN = Regexp.union(*ESCAPE_HTML.keys)
+    if //.respond_to?(:encoding)
+      ESCAPE_HTML_PATTERN = Regexp.union(*ESCAPE_HTML.keys)
+    else
+      # On 1.8, there is a kcode = 'u' bug that allows for XSS otherwhise
+      # TODO doesn't apply to jruby, so a better condition above might be preferable?
+      ESCAPE_HTML_PATTERN = /#{Regexp.union(*ESCAPE_HTML.keys)}/n
+    end
 
     # Escape ampersands, brackets and quotes to their HTML/XML entities.
     def escape_html(string)
